@@ -20,17 +20,17 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 */
 
-#include <Lum/Model/Table.h>
-
 #include <Lum/Dlg/Progress.h>
 
+#include <Package.h>
+
 class PackageListTask : public Lum::Dlg::ProgressTask
 {
 private:
-  Lum::Model::ListTableRef& packages;
+  PackageModelRef& packages;
 
 public:
-  PackageListTask(Lum::Model::ListTableRef& packages);
+  PackageListTask(PackageModelRef& packages);
   void Run();
 };
 
